@@ -71,6 +71,8 @@
 #include <Qt3DAnimation/qabstractanimationclip.h>
 #include <Qt3DAnimation/qabstractclipanimator.h>
 #include <Qt3DAnimation/qanimationclip.h>
+#include <Qt3DAnimation/qchannel.h>
+#include <Qt3DAnimation/qchannelcomponent.h>
 #include <Qt3DAnimation/qanimationcallback.h>
 #include <Qt3DAnimation/qskeletonmapping.h>
 #include <Qt3DAnimation/qadditiveclipblend.h>
@@ -80,16 +82,17 @@
 #include <Qt3DAnimation/qclipanimator.h>
 #include <Qt3DAnimation/qmorphinganimation.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -117,22 +120,24 @@ enum : int {
     SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX               = 16,
     SBK_QT3DANIMATION_QANIMATIONGROUP_IDX                    = 17,
     SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX               = 18,
-    SBK_QT3DANIMATION_QCHANNELMAPPER_IDX                     = 19,
-    SBK_QT3DANIMATION_QCHANNELMAPPING_IDX                    = 20,
-    SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                      = 21,
-    SBK_QT3DANIMATION_QCLIPBLENDVALUE_IDX                    = 22,
-    SBK_QT3DANIMATION_QCLOCK_IDX                             = 23,
-    SBK_QT3DANIMATION_QKEYFRAME_INTERPOLATIONTYPE_IDX        = 25,
-    SBK_QT3DANIMATION_QKEYFRAME_IDX                          = 24,
-    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX      = 27,
-    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                 = 26,
-    SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                     = 28,
-    SBK_QT3DANIMATION_QMORPHTARGET_IDX                       = 29,
-    SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX          = 31,
-    SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                 = 30,
-    SBK_QT3DANIMATION_QSKELETONMAPPING_IDX                   = 32,
-    SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX              = 33,
-    SBK_Qt3DAnimation_IDX_COUNT                              = 34
+    SBK_QT3DANIMATION_QCHANNEL_IDX                           = 19,
+    SBK_QT3DANIMATION_QCHANNELCOMPONENT_IDX                  = 20,
+    SBK_QT3DANIMATION_QCHANNELMAPPER_IDX                     = 21,
+    SBK_QT3DANIMATION_QCHANNELMAPPING_IDX                    = 22,
+    SBK_QT3DANIMATION_QCLIPANIMATOR_IDX                      = 23,
+    SBK_QT3DANIMATION_QCLIPBLENDVALUE_IDX                    = 24,
+    SBK_QT3DANIMATION_QCLOCK_IDX                             = 25,
+    SBK_QT3DANIMATION_QKEYFRAME_INTERPOLATIONTYPE_IDX        = 27,
+    SBK_QT3DANIMATION_QKEYFRAME_IDX                          = 26,
+    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_REPEATMODE_IDX      = 29,
+    SBK_QT3DANIMATION_QKEYFRAMEANIMATION_IDX                 = 28,
+    SBK_QT3DANIMATION_QLERPCLIPBLEND_IDX                     = 30,
+    SBK_QT3DANIMATION_QMORPHTARGET_IDX                       = 31,
+    SBK_QT3DANIMATION_QMORPHINGANIMATION_METHOD_IDX          = 33,
+    SBK_QT3DANIMATION_QMORPHINGANIMATION_IDX                 = 32,
+    SBK_QT3DANIMATION_QSKELETONMAPPING_IDX                   = 34,
+    SBK_QT3DANIMATION_QVERTEXBLENDANIMATION_IDX              = 35,
+    SBK_Qt3DAnimation_IDX_COUNT                              = 36
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_Qt3DAnimationTypes;
@@ -187,6 +192,8 @@ template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationClipLoader >
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationController >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONCONTROLLER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QAnimationGroup >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QANIMATIONGROUP_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QBlendedClipAnimator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QBLENDEDCLIPANIMATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QChannel >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCHANNEL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QChannelComponent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCHANNELCOMPONENT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QChannelMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCHANNELMAPPER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QChannelMapping >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCHANNELMAPPING_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DAnimation::QClipAnimator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_Qt3DAnimationTypes[SBK_QT3DANIMATION_QCLIPANIMATOR_IDX]); }
