@@ -73,16 +73,17 @@
 #include <Qt3DCore/qabstractfunctor.h>
 #include <Qt3DCore/qabstractskeleton.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -91,39 +92,39 @@
 
 // Type indices
 enum : int {
-    SBK_Qt3DCoreQT3DCORE_IDX                                 = 1,
-    SBK_QT3DCORE_QABSTRACTASPECT_IDX                         = 2,
-    SBK_QT3DCORE_QABSTRACTFUNCTOR_IDX                        = 3,
-    SBK_QT3DCORE_QABSTRACTSKELETON_IDX                       = 4,
-    SBK_QT3DCORE_QARMATURE_IDX                               = 5,
-    SBK_QT3DCORE_QASPECTENGINE_RUNMODE_IDX                   = 7,
-    SBK_QT3DCORE_QASPECTENGINE_IDX                           = 6,
-    SBK_QT3DCORE_QASPECTJOB_IDX                              = 8,
-    SBK_QT3DCORE_QATTRIBUTE_ATTRIBUTETYPE_IDX                = 10,
-    SBK_QT3DCORE_QATTRIBUTE_VERTEXBASETYPE_IDX               = 11,
-    SBK_QT3DCORE_QATTRIBUTE_IDX                              = 9,
-    SBK_QT3DCORE_QBACKENDNODE_MODE_IDX                       = 13,
-    SBK_QT3DCORE_QBACKENDNODE_IDX                            = 12,
-    SBK_QT3DCORE_QBACKENDNODEMAPPER_IDX                      = 14,
-    SBK_QT3DCORE_QBOUNDINGVOLUME_IDX                         = 15,
-    SBK_QT3DCORE_QBUFFER_USAGETYPE_IDX                       = 18,
-    SBK_QT3DCORE_QBUFFER_ACCESSTYPE_IDX                      = 17,
-    SBK_QT3DCORE_QBUFFER_IDX                                 = 16,
-    SBK_QT3DCORE_QCOMPONENT_IDX                              = 19,
-    SBK_QT3DCORE_QCORESETTINGS_IDX                           = 20,
-    SBK_QT3DCORE_QENTITY_IDX                                 = 21,
-    SBK_QT3DCORE_QGEOMETRY_IDX                               = 22,
-    SBK_QT3DCORE_QGEOMETRYVIEW_PRIMITIVETYPE_IDX             = 24,
-    SBK_QT3DCORE_QGEOMETRYVIEW_IDX                           = 23,
-    SBK_QT3DCORE_QJOINT_IDX                                  = 25,
-    SBK_QT3DCORE_QNODE_IDX                                   = 26,
-    SBK_QT3DCORE_QNODEID_IDX                                 = 27,
-    SBK_QT3DCORE_QNODEIDTYPEPAIR_IDX                         = 28,
-    SBK_QT3DCORE_QSKELETON_IDX                               = 29,
-    SBK_QT3DCORE_QSKELETONLOADER_STATUS_IDX                  = 31,
-    SBK_QT3DCORE_QSKELETONLOADER_IDX                         = 30,
-    SBK_QT3DCORE_QTRANSFORM_IDX                              = 32,
-    SBK_Qt3DCore_IDX_COUNT                                   = 33
+    SBK_Qt3DCoreQT3DCORE_IDX                                 = 0,
+    SBK_QT3DCORE_QABSTRACTASPECT_IDX                         = 1,
+    SBK_QT3DCORE_QABSTRACTFUNCTOR_IDX                        = 2,
+    SBK_QT3DCORE_QABSTRACTSKELETON_IDX                       = 3,
+    SBK_QT3DCORE_QARMATURE_IDX                               = 4,
+    SBK_QT3DCORE_QASPECTENGINE_RUNMODE_IDX                   = 6,
+    SBK_QT3DCORE_QASPECTENGINE_IDX                           = 5,
+    SBK_QT3DCORE_QASPECTJOB_IDX                              = 7,
+    SBK_QT3DCORE_QATTRIBUTE_ATTRIBUTETYPE_IDX                = 9,
+    SBK_QT3DCORE_QATTRIBUTE_VERTEXBASETYPE_IDX               = 10,
+    SBK_QT3DCORE_QATTRIBUTE_IDX                              = 8,
+    SBK_QT3DCORE_QBACKENDNODE_MODE_IDX                       = 12,
+    SBK_QT3DCORE_QBACKENDNODE_IDX                            = 11,
+    SBK_QT3DCORE_QBACKENDNODEMAPPER_IDX                      = 13,
+    SBK_QT3DCORE_QBOUNDINGVOLUME_IDX                         = 14,
+    SBK_QT3DCORE_QBUFFER_USAGETYPE_IDX                       = 17,
+    SBK_QT3DCORE_QBUFFER_ACCESSTYPE_IDX                      = 16,
+    SBK_QT3DCORE_QBUFFER_IDX                                 = 15,
+    SBK_QT3DCORE_QCOMPONENT_IDX                              = 18,
+    SBK_QT3DCORE_QCORESETTINGS_IDX                           = 19,
+    SBK_QT3DCORE_QENTITY_IDX                                 = 20,
+    SBK_QT3DCORE_QGEOMETRY_IDX                               = 21,
+    SBK_QT3DCORE_QGEOMETRYVIEW_PRIMITIVETYPE_IDX             = 23,
+    SBK_QT3DCORE_QGEOMETRYVIEW_IDX                           = 22,
+    SBK_QT3DCORE_QJOINT_IDX                                  = 24,
+    SBK_QT3DCORE_QNODE_IDX                                   = 25,
+    SBK_QT3DCORE_QNODEID_IDX                                 = 26,
+    SBK_QT3DCORE_QNODEIDTYPEPAIR_IDX                         = 27,
+    SBK_QT3DCORE_QSKELETON_IDX                               = 28,
+    SBK_QT3DCORE_QSKELETONLOADER_STATUS_IDX                  = 30,
+    SBK_QT3DCORE_QSKELETONLOADER_IDX                         = 29,
+    SBK_QT3DCORE_QTRANSFORM_IDX                              = 31,
+    SBK_Qt3DCore_IDX_COUNT                                   = 32
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_Qt3DCoreTypes;
