@@ -78,16 +78,17 @@
 #include <QtQml/qqmlscriptstring.h>
 #include <QtQml/qqmlproperty.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -177,9 +178,10 @@ enum : int {
     SBK_QTQML_QLIST_QJSVALUE_IDX                             = 3, // QList<QJSValue >
     SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 4, // QList<QObject* >
     SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 5, // QList<QByteArray >
-    SBK_QTQML_QLIST_QVARIANT_IDX                             = 6, // QList<QVariant >
-    SBK_QTQML_QLIST_QSTRING_IDX                              = 7, // QList<QString >
-    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 8
+    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 6, // QList<QQmlAbstractUrlInterceptor* >
+    SBK_QTQML_QLIST_QVARIANT_IDX                             = 7, // QList<QVariant >
+    SBK_QTQML_QLIST_QSTRING_IDX                              = 8, // QList<QString >
+    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 9
 };
 // Macros for type check
 
