@@ -83,16 +83,17 @@
 #include <QtQuick/qsgmaterial.h>
 #include <QtQuick/qsgsimpletexturenode.h>
 // Conversion Includes - Primitive Types
+#include <QAnyStringView>
 #include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
-#include <signalmanager.h>
 
 // Conversion Includes - Container Types
 #include <pysideqflags.h>
 #include <QList>
 #include <QMap>
+#include <pysideqflags.h>
 #include <QMultiMap>
 #include <QPair>
 #include <QQueue>
@@ -322,7 +323,7 @@ template<> inline PyTypeObject *SbkType< ::QSGTextureMaterial >() { return reint
 template<> inline PyTypeObject *SbkType< ::QSGTextureProvider >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuickTypes[SBK_QSGTEXTUREPROVIDER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGTransformNode >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuickTypes[SBK_QSGTRANSFORMNODE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGVertexColorMaterial >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuickTypes[SBK_QSGVERTEXCOLORMATERIAL_IDX]); }
-template<> inline PyTypeObject *SbkType< ::QSharedPointer<QQuickItemGrabResult > >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuickTypes[SBK_QSHAREDPOINTER_QQUICKITEMGRABRESULT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSharedPointer<QQuickItemGrabResult > >() { return SbkPySide6_QtQuickTypes[SBK_QSHAREDPOINTER_QQUICKITEMGRABRESULT_IDX]; }
 QT_WARNING_POP
 
 } // namespace Shiboken
